<?php
// $Horde: turba/lib/Driver/ldap.php,v 1.7 2000/09/23 18:25:22 chuck Exp $

/**
 * Turba directory driver implementation for PHP's LDAP extension.
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @author  Jon Parise <jon@csh.rit.edu>
 * @version $Revision: 1.7 $
 * @since   Turba 0.0.1
 */

class Turba_Driver_ldap extends Turba_Driver {

    // {{{ properties

    /** String containing the hostname of the LDAP server.  */
    var $server = 'localhost';

    /** String containing the LDAP search root. */
    var $root = '';

    /** Handle for the current LDAP connection. */
    var $ds = 0;

    // }}}

    // {{{ constructor
    /**
     * Constructs a new Turba LDAP driver object.
     *
     * @param $params       Hash containing additional configuration parameters.
     */
    function Turba_Driver_ldap($params)
    {
        $this->type = 'ldap';
        $this->params = $params;

        $this->server = $params['server'];
        $this->root = $params['root'];

        if (!($this->ds = ldap_connect($this->server))) {
            return false;
        }
        if (!(ldap_bind($this->ds))) {
            $this->errno = ldap_errno($this->ds);
            $this->errstr = ldap_error($this->ds);
            return false;
        }
    }
    // }}}

    // {{{ search()
    /**
     * Searches the LDAP directory with the given criteria and returns a
     * filtered list of results.
     *
     * @param $criteria     Array containing the search criteria.
     * @param $fields       List of fields to return.
     *
     * @return              Hash containing the search results.
     */
    function search($criteria, $fields)
    {
        $filter = '';
        reset($criteria);
        while (list($key, $val) = each($criteria)) {
            if ($filter != '') $filter .= ', ';
            $filter .= '(' . $key . '=*' . $val . '*)';
        }
        
        /*
         * Four11 (at least) doesn't seem to return 'cn' if you don't ask
         * for 'sn' as well.  Add 'sn' implicitly.
         */
        $attr = $fields;
        if (!in_array('sn', $attr)) $attr[] = 'sn';
        
        /* Send the query to the LDAP server and fetch the matching entries. */
        if (!($res = @ldap_search($this->ds, $this->root, $filter, $attr))) {
            $this->errno = ldap_errno($this->ds);
            $this->errstr = ldap_error($this->ds);
            // FIXME: raise an exception using PEAR error handling
            return array();
        }
        if (!($entries = @ldap_get_entries($this->ds, $res))) {
            $this->errno = ldap_errno($this->ds);
            $this->errstr = ldap_error($this->ds);
            // FIXME: raise an exception using PEAR error handling
            return array();
        }
        
        /* Return only the requested fields (from $fields, above). */
        $results = array();
        for ($i = 0; $i < $entries['count']; $i++) {
            $entry = $entries[$i];
            $addr = array();

            foreach ($fields as $field) {
                $addr[$field] = '';
                if (!empty($entry[$field])) {
                    for ($j = 0; $j < $entry[$field]['count']; $j++) {
                        if (!empty($addr[$field])) $addr[$field] .= ', ';
                        $addr[$field] .= $entry[$field][$j];
                    }
                }
            }

            $results[] = $addr;
        }

        return $results;
    }
    // }}}

    // {{{ close()
    /**
     * Closes the current LDAP connection.
     *
     * @return          The result of the ldap_close() call.
     */
    function close()
    {
        return ldap_close($this->ds);
    }
    // }}}

    // {{{ delete()
    /**
     * Deletes the specified entry from the LDAP directory.
     */
    function delete($entry)
    {
        // TODO: implementation
    }
    // }}}

    // {{{ add()
    /**
     * Adds the specified entry to the LDAP directory.
     */
    function add($entry)
    {
        // TODO: implementation
    }
    // }}}

    // {{{ modify()
    /**
     * Modifies the specified entry in the LDAP directory.
     */
    function modify($entry)
    {
        // TODO: implementation
    }
    // }}}
 
}

?>
