<?php
// $Horde: turba/lib/Driver/sql.php,v 1.8 2000/08/16 20:27:43 chuck Exp $

require_once 'DB.php';

/**
 * Turba directory driver implementation for PHP's PEAR database abstraction
 * layer.
 *
 * @author  Jon Parise <jon@csh.rit.edu>
 * @version $Revision: 1.8 $
 * @since   Turba 0.0.1
 */

class Turba_Driver_sql extends Turba_Driver {

    // {{{ properties

    /** Handle for the current database connection. */
    var $db;

    /** String containg the name of the table in which the entries are
        stored. */
    var $table = '';

    // }}}

    // {{{ constructor
    /**
     * Constructs a new Turba SQL driver object.
     *
     * @param $params       Hash containing additional configuration parameters.
     */
    function Turba_Driver_sql($params)
    {
        $this->type = 'sql';
        $this->params = $params;

        $this->db = &DB::connect($params, true);
        $this->table = $params['table'];
    }
    // }}}

    // {{{ search()
    /**
     * Searches the SQL database with the given criteria and returns a
     * filtered list of results.
     *
     * @param $criteria     Array containing the search criteria.
     * @param $fields       List of fields to return.
     *
     * @return              Hash containing the search results.
     */
    function search($criteria, $fields)
    {
        $where = '';
        reset($criteria);
        while (list($key, $val) = each($criteria)) {
            if (!empty($where)) $where .= ' and ';
            // TODO: relax the search a bit
            $where .= "$key like '$val'";
        }

        $query = 'select ' . implode(', ', $fields) . ' ';
        $query .= 'from ' . $this->table . ' where ' . $where;

        $result = $this->db->query($query);

        $results = array();
        if (isset($result)) {
            $row = $result->fetchRow();
            $entry = array();

            for ($i = 0; $i < count($fields); $i++) {
                $field = $fields[$i];
                $entry[$field] = $row[$i];
            }

            $results[] = $entry;
        }


        return $results;
    }
    // }}}

    // {{{ close()
    /**
     * Closes the current database connection.
     *
     * @return          The result of the disconnect() call.
     */
    function close()
    {
        return $this->db->disconnect();
    }
    // }}}

    // {{{ delete()
    /**
     * Deletes the specified entry from the SQL database.
     */
    function delete($entry)
    {
        // TODO: implementation
    }
    // }}}

    // {{{ add()
    /**
     * Adds the specified entry to the SQL database.
     */
    function add($entry)
    {
        // TODO: implementation
    }
    // }}}

    // {{{ modify()
    /**
     * Modifies the specified entry in the SQL database.
     */
    function modify($entry)
    {
        // TODO: implementation
    }
    // }}}
}

?>
